@@ -1,7 +1,4 @@
-# -*- coding: utf-8 -*-
 # Feed this with git rev-list HEAD --parents
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 import sys
 
 parents = {}
