@@ -129,44 +129,97 @@ def write_asciidoc(cmd, f):
     f.write('Part of the StGit suite - see linkman:stg[1]\n')
 
 
-def sign_options():
-    def callback(option, opt_str, value, parser, sign_str):
-        if parser.values.sign_str not in [None, sign_str]:
-            raise optparse.OptionValueError(
-                'Cannot give more than one of --ack, --sign, --review'
-            )
-        parser.values.sign_str = sign_str
+def trailer_options():
+    def callback(option, opt_str, value, parser, trailer):
+        parser.values.trailers.append((trailer, None))
+
+    def by_callback(option, opt_str, value, parser, trailer):
+        parser.values.trailers.append((trailer, value))
 
     return [
         opt(
             '--sign',
             action='callback',
-            dest='sign_str',
-            args=[],
+            dest='trailers',
+            default=[],
             callback=callback,
             callback_args=('Signed-off-by',),
-            short='Add "Signed-off-by:" line',
-            long='Add a "Signed-off-by:" to the end of the patch.',
+            short='Add "Signed-off-by:" trailer',
+            long=(
+                'Add a "Signed-off-by:" trailer to the end of the message using the '
+                'committer name and email for the trailer value.'
+            ),
+        ),
+        opt(
+            '--sign-by',
+            action='callback',
+            dest='trailers',
+            default=[],
+            callback=by_callback,
+            callback_args=('Signed-off-by',),
+            type='string',
+            metavar='VALUE',
+            short='Add "Signed-off-by:" trailer with custom VALUE',
+            long=(
+                'Add a "Signed-off-by:" trailer with a custom VALUE to the end of the '
+                'message.'
+            ),
         ),
         opt(
             '--ack',
             action='callback',
-            dest='sign_str',
-            args=[],
+            dest='trailers',
+            default=[],
             callback=callback,
             callback_args=('Acked-by',),
-            short='Add "Acked-by:" line',
-            long='Add an "Acked-by:" line to the end of the patch.',
+            short='Add "Acked-by:" trailer',
+            long=(
+                'Add an "Acked-by:" trailer to the end of the message using the '
+                'commiter name and email for the trailer value.'
+            ),
+        ),
+        opt(
+            '--ack-by',
+            action='callback',
+            dest='trailers',
+            default=[],
+            callback=by_callback,
+            callback_args=('Acked-by',),
+            type='string',
+            metavar='VALUE',
+            short='Add "Acked-by:" trailer with custom VALUE',
+            long=(
+                'Add an "Acked-by:" trailer with a custom VALUE to the end of the '
+                'message.'
+            ),
         ),
         opt(
             '--review',
             action='callback',
-            dest='sign_str',
-            args=[],
+            dest='trailers',
+            default=[],
             callback=callback,
             callback_args=('Reviewed-by',),
-            short='Add "Reviewed-by:" line',
-            long='Add a "Reviewed-by:" line to the end of the patch.',
+            short='Add "Reviewed-by:" trailer',
+            long=(
+                'Add a "Reviewed-by:" trailer to the end of the message using the '
+                'commiter name and email for the trailer value.'
+            ),
+        ),
+        opt(
+            '--review-by',
+            action='callback',
+            dest='trailers',
+            default=[],
+            callback=by_callback,
+            callback_args=('Reviewed-by',),
+            type='string',
+            metavar='VALUE',
+            short='Add "Reviewed-by:" trailer with custom VALUE',
+            long=(
+                'Add a "Reviewed-by:" trailer with custom VALUE to the end of the '
+                'message.'
+            ),
         ),
     ]
 
