@@ -67,83 +67,79 @@ Additionally, the '--spill' option resets the topmost patch, emptying
 the patch while leaving the patch's changes intact in the worktree."""
 
 args = ['dirty_files']
-options = (
-    [
-        opt(
-            '-u',
-            '--update',
-            action='store_true',
-            short='Only update the current patch files',
-        ),
-        opt(
-            '-i',
-            '--index',
-            action='store_true',
-            short='Refresh from index instead of worktree',
-            long="""
+options = [
+    opt(
+        '-u',
+        '--update',
+        action='store_true',
+        short='Only update the current patch files',
+    ),
+    opt(
+        '-i',
+        '--index',
+        action='store_true',
+        short='Refresh from index instead of worktree',
+        long="""
         Instead of setting the patch top to the current contents of
         the worktree, set it to the current contents of the index.""",
-        ),
-        opt(
-            '-F',
-            '--force',
-            action='store_true',
-            short='Force refresh even if index is dirty',
-            long="""
+    ),
+    opt(
+        '-F',
+        '--force',
+        action='store_true',
+        short='Force refresh even if index is dirty',
+        long="""
         Instead of warning the user when some work has already been staged
         (such as with git add interactive mode) force a full refresh.""",
-        ),
-        opt(
-            '-p',
-            '--patch',
-            args=['other_applied_patches', 'unapplied_patches'],
-            short='Refresh (applied) PATCH instead of the top patch',
-        ),
-        opt(
-            '-e',
-            '--edit',
-            action='store_true',
-            short='Invoke an editor for the patch description',
-        ),
-        opt(
-            '-d',
-            '--diff',
-            action='store_true',
-            short='Show diff when editing patch description',
-        ),
-        opt(
-            '-a',
-            '--annotate',
-            metavar='NOTE',
-            short='Annotate the patch log entry',
-        ),
-        opt(
-            '-s',
-            '--submodules',
-            action='store_true',
-            short='Include submodules when refreshing patch contents',
-        ),
-        opt(
-            '--no-submodules',
-            action='store_false',
-            dest='submodules',
-            short='Exclude submodules when refreshing patch contents',
-        ),
-        opt(
-            '--spill',
-            action='store_true',
-            dest='spill',
-            short='Spill patch content to worktree and index, erasing patch content.',
-        ),
-    ]
-    + (
-        argparse.message_options(save_template=False)
-        + argparse.hook_options()
-        + argparse.sign_options()
-        + argparse.author_options()
-        + argparse.diff_opts_option()
-    )
-)
+    ),
+    opt(
+        '-p',
+        '--patch',
+        args=['other_applied_patches', 'unapplied_patches'],
+        short='Refresh (applied) PATCH instead of the top patch',
+    ),
+    opt(
+        '-e',
+        '--edit',
+        action='store_true',
+        short='Invoke an editor for the patch description',
+    ),
+    opt(
+        '-d',
+        '--diff',
+        action='store_true',
+        short='Show diff when editing patch description',
+    ),
+    opt(
+        '-a',
+        '--annotate',
+        metavar='NOTE',
+        short='Annotate the patch log entry',
+    ),
+    opt(
+        '-s',
+        '--submodules',
+        action='store_true',
+        short='Include submodules when refreshing patch contents',
+    ),
+    opt(
+        '--no-submodules',
+        action='store_false',
+        dest='submodules',
+        short='Exclude submodules when refreshing patch contents',
+    ),
+    opt(
+        '--spill',
+        action='store_true',
+        dest='spill',
+        short='Spill patch content to worktree and index, erasing patch content.',
+    ),
+]
+options.extend(argparse.message_options(save_template=False))
+options.extend(argparse.hook_options())
+options.extend(argparse.trailer_options())
+options.extend(argparse.author_options())
+options.extend(argparse.diff_opts_option())
 
 directory = DirectoryHasRepository()
 
@@ -261,9 +257,13 @@ def absorb_applied(trans, iw, patch_name, temp_name, edit_fun):
         # Absorb the temp patch.
         temp_cd = trans.patches[temp_name].data
         assert trans.patches[patch_name] == temp_cd.parent
-        trans.patches[patch_name] = trans.stack.repository.commit(
-            edit_fun(trans.patches[patch_name].data.set_tree(temp_cd.tree))
+        cd, new_patch_name = edit_fun(
+            trans.patches[patch_name].data.set_tree(temp_cd.tree)
         )
+        trans.patches[patch_name] = trans.stack.repository.commit(cd)
+        if new_patch_name and patch_name != new_patch_name:
+            trans.rename_patch(patch_name, new_patch_name)
+
         popped_extra = trans.delete_patches(lambda pn: pn == temp_name, quiet=True)
         assert not popped_extra  # the temp patch was topmost
         temp_absorbed = True
@@ -307,9 +307,10 @@ def absorb_unapplied(trans, iw, patch_name, temp_name, edit_fun):
     if new_tree:
         # It worked. Refresh the patch with the new tree, and delete
         # the temp patch.
-        trans.patches[patch_name] = trans.stack.repository.commit(
-            edit_fun(patch_cd.set_tree(new_tree))
-        )
+        cd, new_patch_name = edit_fun(patch_cd.set_tree(new_tree))
+        trans.patches[patch_name] = trans.stack.repository.commit(cd)
+        if new_patch_name and patch_name != new_patch_name:
+            trans.rename_patch(patch_name, new_patch_name)
         popped_extra = trans.delete_patches(lambda pn: pn == temp_name, quiet=True)
         assert not popped_extra  # the temp patch was not applied
         return True
@@ -385,7 +386,7 @@ def __refresh(
     target_patch=None,
     message=None,
     author=None,
-    sign_str=None,
+    trailers=None,
     annotate=None,
     use_temp_index=False,
     refresh_from_index=False,
@@ -466,17 +467,18 @@ def __refresh(
             cd,
             msg=new_msg,
             author=author,
-            sign_str=sign_str,
+            trailers=trailers,
         )
+        new_patch_name = None
         if invoke_editor:
-            cd, failed_diff = interactive_edit_patch(
-                stack.repository, cd, edit_diff, diff_flags
+            cd, new_patch_name, failed_diff = interactive_edit_patch(
+                stack.repository, cd, patch_name, edit_diff, diff_flags
             )
             assert not failed_diff
         if not no_verify and (invoke_editor or cd.message != orig_msg):
             cd = run_commit_msg_hook(stack.repository, cd, invoke_editor)
         # Refresh the committer information
-        return cd.set_committer(None)
+        return cd.set_committer(None), new_patch_name
 
     return absorb(stack, patch_name, temp_name, edit_fun, annotate=annotate)
 
@@ -485,17 +487,22 @@ def func(parser, options, args):
     """Generate a new commit for the current or given patch."""
 
     if options.spill:
-        if (
-            len(args) > 0
-            or options.index
-            or options.edit
-            or options.update
-            or options.patch
-            or options.force
-            or options.no_verify
-            or options.sign_str
-        ):
-            raise CmdException('--spill option does not take any arguments or options')
+        if len(args) > 0:
+            # TODO: would be nice if path limiting could be used with spill.
+            raise CmdException('Cannot use path limiting with --spill')
+        for opt_name, opt_value in [
+            ('--index', options.index),
+            ('--edit', options.edit),
+            ('--update', options.update),
+            ('--patch', options.patch),
+            ('--force', options.force),
+            ('--no-verify', options.no_verify),
+            ('--sign', options.trailers),
+            ('--ack', options.trailers),
+            ('--review', options.trailers),
+        ]:
+            if opt_value:
+                raise CmdException('Cannot combine --spill with %s' % opt_name)
         return __refresh_spill(annotate=options.annotate)
     else:
         # Catch illegal argument combinations.
@@ -529,7 +536,7 @@ def func(parser, options, args):
             target_patch=options.patch,
             message=options.message,
             author=options.author,
-            sign_str=options.sign_str,
+            trailers=options.trailers,
             annotate=options.annotate,
             use_temp_index=is_path_limiting,
             refresh_from_index=options.index,
