@@ -1,8 +1,5 @@
-# -*- coding: utf-8 -*-
 """A Python class hierarchy wrapping a git repository and its contents."""
 
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 from stgit.run import Run
 
 from .branch import Branch
@@ -36,17 +33,6 @@ __all__ = [
 ]
 
 
-def diffstat(diff):
-    """Return the diffstat of the supplied diff."""
-    return (
-        Run('git', 'apply', '--stat', '--summary')
-        .encoding(None)
-        .raw_input(diff)
-        .decoding('utf-8')
-        .raw_output()
-    )
-
-
 def clone(remote, local):
     """Clone a remote repository using 'git clone'."""
     Run('git', 'clone', remote, local).run()
