@@ -8,7 +8,7 @@ test_description='Test the sync command.'
 . ./test-lib.sh
 
 test_expect_success \
-    'Initialize the StGIT repository' \
+    'Initialize the StGit repository' \
     '
     stg init
     '
