@@ -5,13 +5,11 @@ test_description='Run "stg squash"'
 . ./test-lib.sh
 
 test_expect_success 'Initialize StGit stack' '
+    test_commit_bulk --start=0 --filename=foo.txt --contents="foo %s" --message="p%s" 6 &&
     stg init &&
-    for i in 0 1 2 3; do
-        stg new p$i -m "foo $i" &&
-        git notes add -m note$i &&
-        echo "foo $i" >> foo.txt &&
-        stg add foo.txt &&
-        stg refresh
+    stg uncommit -n 6 &&
+    for i in 0 1 2 3 4 5; do
+        git notes add -m "note$i" $(stg id p$i)
     done
 '
 
@@ -30,22 +28,46 @@ test_expect_success 'Attempt invalid patch name' '
     grep -e "Patch name \"invalid..name\" is invalid"
 '
 
+test_expect_success 'Attempt out of order' '
+    conflict stg squash --name=q4 p5 p4 &&
+    stg undo --hard
+'
+
+test_expect_success 'Squash out of order no conflict' '
+    echo hello > bar.txt &&
+    stg add bar.txt &&
+    stg new -m bar-patch &&
+    stg refresh &&
+    stg squash -n q5 bar-patch p5 &&
+    [ "$(echo $(stg series --applied --noprefix))" = "p0 p1 p2 p3 p4 q5" ]
+'
+
+test_expect_success 'Squash out of order no conflict no name' '
+    echo hello > baz.txt &&
+    stg add baz.txt &&
+    stg new -m baz-patch &&
+    stg refresh &&
+    stg squash -m q6 baz-patch q5 &&
+    [ "$(echo $(stg series --applied --noprefix))" = "p0 p1 p2 p3 p4 q6" ]
+'
+
 test_expect_success 'Save template' '
-    stg squash --save-template mytemplate p0 p1 &&
+    stg squash --save-template mytemplate p1 p2 &&
     test_path_is_file mytemplate &&
-    [ "$(echo $(stg series --applied --noprefix))" = "p0 p1 p2 p3" ]
+    [ "$(echo $(stg series --applied --noprefix))" = "p0 p1 p2 p3 p4 q6" ] &&
+    echo "squashed patch" > mytemplate &&
+    stg squash --file=mytemplate p1 p2 &&
+    [ "$(echo $(stg series --applied --noprefix))" = "p0 squashed-patch p3 p4 q6" ]
 '
 
 test_expect_success 'Squash some patches' '
-    [ "$(echo $(stg series --applied --noprefix))" = "p0 p1 p2 p3" ] &&
-    [ "$(echo $(stg series --unapplied --noprefix))" = "" ] &&
-    stg squash --name=q0 --message="wee woo" p1 p2 &&
-    [ "$(echo $(stg series --applied --noprefix))" = "p0 q0 p3" ] &&
+    stg squash --message="wee woo" p3 p4 q6 &&
+    [ "$(echo $(stg series --applied --noprefix))" = "p0 squashed-patch wee-woo" ] &&
     [ "$(echo $(stg series --unapplied --noprefix))" = "" ]
 '
 
 test_expect_success 'Squash at stack top' '
-    stg squash --name=q1 --message="wee woo wham" q0 p3 &&
+    stg squash --name=q1 --message="wee woo wham" squashed-patch wee-woo &&
     [ "$(echo $(stg series --applied --noprefix))" = "p0 q1" ] &&
     [ "$(echo $(stg series --unapplied --noprefix))" = "" ]
 '
