@@ -11,11 +11,6 @@ files*.txt
 status*.txt
 EOF
 
-reset () {
-    stg pop -a > /dev/null
-    git reset --hard > /dev/null
-}
-
 test_expect_success 'Initialize StGit stack' '
     stg init &&
     echo x > x.txt &&
@@ -29,6 +24,7 @@ D  y.txt
 EOF
 printf '' > expected1.txt
 test_expect_success 'stg rm a file' '
+    test_when_finished "stg pop -a; git reset --hard"
     stg new -m p0 &&
     stg rm y.txt &&
     stg status > status0.txt &&
@@ -40,14 +36,13 @@ test_expect_success 'stg rm a file' '
     test_cmp -w expected0.txt files.txt
 '
 
-reset
-
 cat > expected0.txt <<EOF
  M x.txt
 D  y.txt
 EOF
 printf '' > expected1.txt
 test_expect_success 'stg rm a file together with other changes' '
+    test_when_finished "stg pop -a; git reset --hard"
     stg new -m p1 &&
     echo x2 >> x.txt &&
     stg rm y.txt &&
@@ -60,13 +55,12 @@ test_expect_success 'stg rm a file together with other changes' '
     test_cmp -w expected0.txt files.txt
 '
 
-reset
-
 cat > expected0.txt <<EOF
  D y.txt
 EOF
 printf '' > expected1.txt
 test_expect_success 'rm a file' '
+    test_when_finished "stg pop -a; git reset --hard"
     stg new -m p2 &&
     rm y.txt &&
     stg status > status0.txt &&
@@ -78,14 +72,13 @@ test_expect_success 'rm a file' '
     test_cmp -w expected0.txt files.txt
 '
 
-reset
-
 cat > expected0.txt <<EOF
  M x.txt
  D y.txt
 EOF
 printf '' > expected1.txt
 test_expect_success 'rm a file together with other changes' '
+    test_when_finished "stg pop -a; git reset --hard"
     stg new -m p3 &&
     echo x2 >> x.txt &&
     rm y.txt &&
