@@ -40,7 +40,7 @@ test_expect_success 'Pop middle patch, creating a conflict' '
 '
 
 test_expect_success 'Try to reset without --hard' '
-    command_error stg reset master.stgit^~1 &&
+    command_error stg reset refs/stacks/master^~1 &&
     stg status a > actual.txt &&
     test_cmp expected.txt actual.txt &&
     test "$(echo $(stg series))" = "+ p1 > p3 - p2"
@@ -49,7 +49,7 @@ test_expect_success 'Try to reset without --hard' '
 cat > expected.txt <<EOF
 EOF
 test_expect_success 'Try to reset with --hard' '
-    stg reset --hard master.stgit^~1 &&
+    stg reset --hard refs/stacks/master^~1 &&
     stg status a > actual.txt &&
     test_cmp expected.txt actual.txt &&
     test "$(echo $(stg series))" = "+ p1 + p2 > p3"
